@@ -92,6 +92,18 @@ class People(PeopleAbridged):
             'individual person in the room.'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['occupancy_schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+            schema['properties']['activity_schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 class LightingAbridged(IDdEnergyBaseModel):
 
@@ -160,6 +172,14 @@ class Lighting(LightingAbridged):
             'complete lighting profile.'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 class _EquipmentBase(IDdEnergyBaseModel):
 
@@ -232,6 +252,14 @@ class ElectricEquipment(ElectricEquipmentAbridged):
             'a complete equipment profile.'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 class GasEquipmentAbridged(_EquipmentBase):
 
@@ -250,6 +278,14 @@ class GasEquipment(GasEquipmentAbridged):
             'a complete equipment profile.'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 class InfiltrationAbridged(IDdEnergyBaseModel):
 
@@ -299,6 +335,14 @@ class Infiltration(InfiltrationAbridged):
             'to yield a complete infiltration profile.'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 class VentilationAbridged(IDdEnergyBaseModel):
 
@@ -357,6 +401,14 @@ class Ventilation(VentilationAbridged):
             'ventilation profile.'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 class SetpointAbridged(IDdEnergyBaseModel):
     """Used to specify information about the setpoint schedule."""
@@ -438,6 +490,26 @@ class Setpoint(SetpointAbridged):
             'in this schedule should be in [%].'
     )
 
+    class Config:
+        @staticmethod
+        def schema_extra(schema, model):
+            schema['properties']['cooling_schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+            schema['properties']['heating_schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+            schema['properties']['humidifying_schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+            schema['properties']['dehumidifying_schedule']['anyOf'] = [
+                    {"$ref": "#/components/schemas/ScheduleRuleset"},
+                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
+                ]
+
 
 if __name__ == '__main__':
     print(PeopleAbridged.schema_json(indent=2))
