@@ -1,6 +1,6 @@
 from honeybee_schema.energy.constructionset import ConstructionSetAbridged, \
     WallSetAbridged, RoofCeilingSetAbridged, FloorSetAbridged, ApertureSetAbridged, \
-    DoorSetAbridged
+    DoorSetAbridged, ConstructionSet
 import os
 
 # target folder where all of the samples live
@@ -9,10 +9,21 @@ target_folder = os.path.join(root, 'samples', 'construction_set')
 
 
 def test_constructionset_complete():
-    file_path = os.path.join(target_folder, 'constructionset_complete.json')
+    file_path = os.path.join(target_folder, 'constructionset_abridged_complete.json')
     ConstructionSetAbridged.parse_file(file_path)
 
 
 def test_constructionset_partial_exterior():
-    file_path = os.path.join(target_folder, 'constructionset_partial_exterior.json')
+    file_path = os.path.join(target_folder, 'constructionset_abridged_partial_exterior.json')
     ConstructionSetAbridged.parse_file(file_path)
+
+
+def test_constructionset_complete():
+    file_path = os.path.join(target_folder, 'constructionset_complete.json')
+    ConstructionSet.parse_file(file_path)
+
+
+def test_constructionset_partial_exterior():
+    file_path = os.path.join(target_folder, 'constructionset_partial_exterior.json')
+    ConstructionSet.parse_file(file_path)
+
